@@ -47,16 +47,16 @@ class DeviceProfileNegativeTest(base.BaseAPITest):
 
     @test.attr(type=['negative', 'gate'])
     def test_create_device_profile_server_fault(self):
-        # create device profile name same
+        # create device profile with the same uuid
         dp = [{
-            "name": "fpga_same_test",
+            "name": "fpga_uuid_test",
             "groups": [
                 {
                     "resources:FPGA": "1",
                     "trait:CUSTOM_FAKE_DEVICE": "required"
                 }]
         }]
-        # create a device profile with named "fpga_same_test"
+        # create a device profile with named "fpga_uuid_test"
         response = self.os_admin.cyborg_client.create_device_profile(dp)
         self.assertEqual(dp[0]['name'], response['name'])
         self.addCleanup(self.os_admin.cyborg_client.delete_device_profile,
@@ -91,3 +91,21 @@ class DeviceProfileNegativeTest(base.BaseAPITest):
         self.assertRaises(lib_exc.Conflict,
                           self.os_admin.cyborg_client.create_device_profile,
                           dp)
+
+    @test.attr(type=['negative', 'gate'])
+    def test_create_device_profile_name_is_null(self):
+        # create device profile name is null
+        dp = [{
+            "name": "",
+            "groups": [
+                {
+                    "resources:FPGA": "1",
+                    "trait:CUSTOM_FAKE_DEVICE": "required"
+                }],
+            "description": "null"
+        }]
+
+        # create device profile with name null
+        self.assertRaises(lib_exc.ServerFault,
+                          self.os_admin.cyborg_client.create_device_profile,
+                          dp)
